@@ -8,8 +8,7 @@ use lib::counter::*;
 
 const CONFIG_DIR: &str = "take-breath";
 const CONFIG_FILE: &str = "config.toml";
-const CONFIG_COMMENT_STRING: &str = r#"
-# Configuration for Take Breath
+const CONFIG_COMMENT_STRING: &str = r#"# Configuration for Take Breath
 # See https://github.com/markmelix/take-breath#customization"#;
 
 fn main() {
@@ -53,7 +52,8 @@ fn main() {
 	None => eprintln!("Error: config directory not found"),
     }
 
-    config.apply_env();
+    #[cfg(debug_assertions)]
+    println!("{:#?}", config);
 
     let work = Work::new(
 	config.work_time.duration,
